@@ -17,9 +17,9 @@ sub mvp_multivalue_args { qw(
                         ) }
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2024-02-13'; # DATE
+our $DATE = '2024-02-19'; # DATE
 our $DIST = 'Pod-Weaver-Plugin-Sah-SchemaBundle'; # DIST
-our $VERSION = '0.080'; # VERSION
+our $VERSION = '0.081'; # VERSION
 
 sub weave_section {
     no strict 'refs'; ## no critic: TestingAndDebugging::ProhibitNoStrict
@@ -177,10 +177,11 @@ sub weave_section {
 
                 # link to completion modules
                 my $xcompletions = $sch->[1]{'x.completion'};
-                if ($xcompletions && @$xcompletions) {
+                if ($xcompletions) {
+                    $xcompletions = [$xcompletions] unless ref $xcompletions eq 'ARRAY';
                     push @pod, "Used completion: ";
                     for my $i (0 .. $#{$xcompletions}) {
-                        my $cname = ref $xcompletions->[$i] ? $xcompletions->[$i][0] : $xcompletions->[$i];
+                        my $cname = ref $xcompletions->[$i] eq 'ARRAY' ? $xcompletions->[$i][0] : $xcompletions->[$i];
                         push @pod, ", " if $i; push @pod, "L<$cname|Perinci::Sub::XCompletion::$cname>" }
                     push @pod, "\n\n";
                 }
@@ -455,7 +456,7 @@ Pod::Weaver::Plugin::Sah::SchemaBundle - Plugin to use when building Sah::Schema
 
 =head1 VERSION
 
-This document describes version 0.080 of Pod::Weaver::Plugin::Sah::SchemaBundle (from Perl distribution Pod-Weaver-Plugin-Sah-SchemaBundle), released on 2024-02-13.
+This document describes version 0.081 of Pod::Weaver::Plugin::Sah::SchemaBundle (from Perl distribution Pod-Weaver-Plugin-Sah-SchemaBundle), released on 2024-02-19.
 
 =head1 SYNOPSIS
 
